@@ -1,7 +1,11 @@
 package MooseX::App;
 # ============================================================================«
+
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = '1.00';
+our $VERSION = '1.01';
+
+use strict;
+use warnings;
 
 use Moose::Exporter;
 
@@ -106,7 +110,7 @@ __END__
 
 =head1 NAME
 
-MooseX::App - write user-friendly command line apps with even less suffering
+MooseX::App - Write user-friendly command line apps with even less suffering
 
 =head1 SYNOPSIS
 
@@ -236,4 +240,4 @@ This library is free software and may be distributed under the same terms as
 perl itself. The full text of the licence can be found in the LICENCE file 
 included with this module.
 
-1;
\ No newline at end of file
+=cut
\ No newline at end of file
